
# Copyright (c) 2010 - Luca Invernizzi <invernizzi.l@gmail.com>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.

from GTG.core.translations import _

title = _("Foldable booklet (PDF)")
description = _("""A template to create
<a href="http://www.pocketmod.com">PocketMod</a>, which is a small foldable
booklet. Packages <b>pdflatex</b>, <b>pdftk</b> and <b>pdfjam</b>
are required.""")
